summary refs log tree commit diff
path: root/gnu/packages
diff options
context:
space:
mode:
authorManolis Ragkousis <manolis837@gmail.com>2016-04-10 21:20:51 +0300
committerManolis Ragkousis <manolis837@gmail.com>2016-05-10 14:39:50 +0300
commit55de892b435657f82a25c6499174d09b4a680f15 (patch)
treec93c2cccbf8a33b915bd9d9c56e30b957eeda68f /gnu/packages
parent6ea06a0e3a161be52a8f0b006f29901ccf1c079a (diff)
downloadguix-55de892b435657f82a25c6499174d09b4a680f15.tar.gz
gnu: glibc: Rename linux-headers input to kernel-headers.
* gnu/packages/base.scm (glibc)[propagated-inputs]: Use a kernel
  agnostic name for the kernel headers.
  [arguments]: Adjust accordingly.
* gnu/packages/commencement.scm (glibc-final-with-bootstrap-bash)
  [propagated-inputs]: Adjust accordingly.
* gnu/packages/cross-base.scm (cross-gcc-arguments)[arguments]: Adjust
  accordingly.
  (cross-gcc)[native-inputs]: Adjust accordingly.
* gnu/packages/make-bootstrap.scm (%glibc-stripped)[arguments]: Adjust
  accordingly.
  [inputs]: Adjust accordingly.
Diffstat (limited to 'gnu/packages')
-rw-r--r--gnu/packages/base.scm4
-rw-r--r--gnu/packages/commencement.scm2
-rw-r--r--gnu/packages/cross-base.scm24
-rw-r--r--gnu/packages/make-bootstrap.scm4
4 files changed, 17 insertions, 17 deletions
diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index fce193ceec..d7e069edee 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -479,7 +479,7 @@ store.")
 
    ;; Glibc's <limits.h> refers to <linux/limit.h>, for instance, so glibc
    ;; users should automatically pull Linux headers as well.
-   (propagated-inputs `(("linux-headers" ,linux-libre-headers)))
+   (propagated-inputs `(("kernel-headers" ,linux-libre-headers)))
 
    (outputs '("out" "debug"))
 
@@ -519,7 +519,7 @@ store.")
                            ,version)
 
             (string-append "--with-headers="
-                           (assoc-ref %build-inputs "linux-headers")
+                           (assoc-ref %build-inputs "kernel-headers")
                            "/include")
 
             ;; This is the default for most architectures as of GNU libc 2.21,
diff --git a/gnu/packages/commencement.scm b/gnu/packages/commencement.scm
index 463f42537c..12cafb78e5 100644
--- a/gnu/packages/commencement.scm
+++ b/gnu/packages/commencement.scm
@@ -382,7 +382,7 @@
                                    "export CPATH\n"
                                    all "\n"))))
                ,phases)))))
-     (propagated-inputs `(("linux-headers" ,(linux-libre-headers-boot0))))
+     (propagated-inputs `(("kernel-headers" ,(linux-libre-headers-boot0))))
      (native-inputs
       `(("texinfo" ,texinfo-boot0)
         ("perl" ,perl-boot0)))
diff --git a/gnu/packages/make-bootstrap.scm b/gnu/packages/make-bootstrap.scm
index 85dfaa6b6f..def9c23b17 100644
--- a/gnu/packages/make-bootstrap.scm
+++ b/gnu/packages/make-bootstrap.scm
@@ -344,7 +344,7 @@ for `sh' in $PATH, and without nscd, and with static NSS modules."
                   (libdir (string-append out "/lib"))
                   (incdir (string-append out "/include"))
                   (libc   (assoc-ref %build-inputs "libc"))
-                  (linux  (assoc-ref %build-inputs "linux-headers")))
+                  (linux  (assoc-ref %build-inputs "kernel-headers")))
              (mkdir-p libdir)
              (for-each (lambda (file)
                          (let ((target (string-append libdir "/"
@@ -379,7 +379,7 @@ for `sh' in $PATH, and without nscd, and with static NSS modules."
                                 (parameterize ((%current-target-system #f))
                                   (cross-libc target)))
                                glibc)))
-                ("linux-headers" ,linux-libre-headers)))
+                ("kernel-headers" ,linux-libre-headers)))
 
       ;; Only one output.
       (outputs '("out")))))
diff --git a/gnu/packages/cross-base.scm b/gnu/packages/cross-base.scm
index aa67d21c19..22dfa15674 100644
--- a/gnu/packages/cross-base.scm
+++ b/gnu/packages/cross-base.scm
@@ -166,18 +166,18 @@ may be either a libc package or #f.)"
               `(alist-cons-before
                 'configure 'set-cross-path
                 (lambda* (#:key inputs #:allow-other-keys)
                   ;; Add the cross Linux headers to CROSS_CPATH, and remove them
                   ;; from CPATH.
                   (let ((libc  (assoc-ref inputs "libc"))
-                        (linux (assoc-ref inputs "xlinux-headers")))
+                        (kernel (assoc-ref inputs "xkernel-headers")))
                     (define (cross? x)
                       ;; Return #t if X is a cross-libc or cross Linux.
                       (or (string-prefix? libc x)
-                          (string-prefix? linux x)))
+                          (string-prefix? kernel x)))
 
                     (setenv "CROSS_CPATH"
                             (string-append libc "/include:"
-                                           linux "/include"))
+                                           kernel "/include"))
                     (setenv "CROSS_LIBRARY_PATH"
                             (string-append libc "/lib"))
 
@@ -250,9 +250,9 @@ GCC that does not target a libc; otherwise, target that libc."
                                (alist-delete "libc" %final-inputs))))
            (if libc
                `(("libc" ,libc)
-                 ("xlinux-headers"                ;the target headers
+                 ("xkernel-headers"                ;the target headers
                   ,@(assoc-ref (package-propagated-inputs libc)
-                               "linux-headers"))
+                               "kernel-headers"))
                  ,@inputs)
                inputs))))
 
@@ -314,17 +314,17 @@ XBINUTILS and the cross tool chain."
                ,flags))
        ((#:phases phases)
         `(alist-cons-before
-          'configure 'set-cross-linux-headers-path
+          'configure 'set-cross-kernel-headers-path
           (lambda* (#:key inputs #:allow-other-keys)
-            (let ((linux (assoc-ref inputs "linux-headers")))
+            (let ((kernel (assoc-ref inputs "kernel-headers")))
               (setenv "CROSS_CPATH"
-                      (string-append linux "/include"))
+                      (string-append kernel "/include"))
               #t))
           ,phases))))
 
-    ;; Shadow the native "linux-headers" because glibc's recipe expects the
-    ;; "linux-headers" input to point to the right thing.
-    (propagated-inputs `(("linux-headers" ,xlinux-headers)))
+    ;; Shadow the native "kernel-headers" because glibc's recipe expects the
+    ;; "kernel-headers" input to point to the right thing.
+    (propagated-inputs `(("kernel-headers" ,xlinux-headers)))
 
     ;; FIXME: 'static-bash' should really be an input, not a native input, but
     ;; to do that will require building an intermediate cross libc.
@@ -166,18 +166,18 @@ may be either a libc package or #f.)"
                 'configure 'set-cross-path
                 (lambda* (#:key inputs #:allow-other-keys)
-                  ;; Add the cross Linux headers to CROSS_CPATH, and remove them
+                  ;; Add the cross kernel headers to CROSS_CPATH, and remove them
                   ;; from CPATH.
                   (let ((libc  (assoc-ref inputs "libc"))